package com.nisum.ecomservice.controller;

import com.nisum.ecomservice.model.Product;
import com.nisum.ecomservice.model.Promotion;
import com.nisum.ecomservice.service.ProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("/api")
@CrossOrigin(origins = "*")
public class ProductsController {

    @Autowired
    private ProductService productService;

    @GetMapping("/products-and-promos")
    public ResponseEntity<Flux<?>> getAllProductsAndPromos() {
        Flux<Product> products = productService.getAllProducts();
        Flux<Promotion> promotions = productService.getAllPromotions();

        return ResponseEntity.ok(Flux.merge(products, promotions));
    }

    @GetMapping("/products")
    public ResponseEntity<Flux<Product>> getAllProducts() {
        return ResponseEntity.ok(productService.getAllProducts());
    }

    @GetMapping("/promos")
    public ResponseEntity<Flux<Promotion>> getAllPromos() {
        return ResponseEntity.ok(productService.getAllPromotions());
    }

    @GetMapping("/products/{sku}")
    public ResponseEntity<Mono<Product>> getProductBySku(@PathVariable String sku) {
        return ResponseEntity.ok(productService.getProductBySku(sku));
    }



}
