package com.nisum.ecomservice.service;

import com.nisum.ecomservice.model.Product;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.reactive.function.client.WebClient;
import reactor.core.publisher.Mono;
import com.nisum.ecomservice.model.Promotion;
import reactor.core.publisher.Flux;

import java.util.List;


@Service
public class ProductService {

    @Value("${products.apiUrl}")
    private String productsManagementUrl;

    @Value("${promos.apiUrl}")
    private String promoManagementUrl;

    public Mono<Product> getProductBySku(String sku){
        return WebClient.create(String.format("%s/api/products/%s", productsManagementUrl,sku))
                .get()
                .retrieve()
                .bodyToMono(Product.class);
    }

    public Flux<Product> getAllProducts() {
        return WebClient
                .builder()
                .baseUrl(productsManagementUrl)
                .build()
                .get()
                .uri("/api/products")
                .retrieve()
                .bodyToFlux(Product.class);
    }

    public Flux<Promotion> getAllPromotions() {
        return WebClient
                .builder()
                .baseUrl(promoManagementUrl)
                .build()
                .get()
                .uri("/api/promos")
                .retrieve()
                .bodyToFlux(Promotion.class);
    }

    public Flux<Promotion> getPromotionBySkus(List<String> listOfSkus){
        return WebClient.create(String.format("%s/api/promos/bulkSearch",promoManagementUrl))
                .post()
                .bodyValue(listOfSkus)
                .retrieve()
                .bodyToFlux(Promotion.class);
    }

}
