import React from 'react';
import { totalPrice } from '../../util/order_history_util';
import OrderItem from './OrderItem';


const Order = (props) => {

    const {order, alt} = props;
    const {orderItems, customerAddress} = order;

    const orderTotalPrice = totalPrice(orderItems);
    const orderPlaced = new Date(order.orderCreatedAt);

    return (
        <div className={`order order-${alt%2}`}>
            <p className="order-number">Order #: {order.id}</p>
            <div className="products-ordered">
                {orderItems.map((orderItem, ind) => {
                    return (
                        <OrderItem key={ind} orderItem={orderItem} />
                    )
                })}
            </div>
            <div className="total-price">
            <p><span className="order-field">Total Price:</span> ${orderTotalPrice}</p>
            </div>
            <div className="order-details">
                <div className="order-description">
                    <p className="order-status-header">Status</p>
                    <p><span className="order-field">Order Placed:</span> {orderPlaced.getUTCMonth()}
                    /{orderPlaced.getUTCDay()}
                    /{orderPlaced.getUTCFullYear()}
                    </p>
                    <p><span className="order-field">Order Status:</span> {order.orderStatus}</p>
                </div>
                <div className="shipping-details">
                    <p className="shipping-details-header">Shipping Address</p>
                    <span>{customerAddress.street},</span>
                    <p>{`${customerAddress.city},
                    ${customerAddress.state} ${customerAddress.zip}
                    `}
                    </p>
                </div>
            </div>
        </div>
    )
}

export default Order;